# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainMonitorDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'domain': 'str',
        'name': 'str',
        'interval_seconds': 'int',
        'enabled': 'bool',
        'scheduling_enabled': 'bool',
        'last_status': 'str',
        'health_score': 'int',
        'last_run_at': 'datetime',
        'next_run_at': 'datetime',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'domain': 'domain',
        'name': 'name',
        'interval_seconds': 'intervalSeconds',
        'enabled': 'enabled',
        'scheduling_enabled': 'schedulingEnabled',
        'last_status': 'lastStatus',
        'health_score': 'healthScore',
        'last_run_at': 'lastRunAt',
        'next_run_at': 'nextRunAt',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, user_id=None, domain=None, name=None, interval_seconds=None, enabled=None, scheduling_enabled=None, last_status=None, health_score=None, last_run_at=None, next_run_at=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DomainMonitorDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._domain = None
        self._name = None
        self._interval_seconds = None
        self._enabled = None
        self._scheduling_enabled = None
        self._last_status = None
        self._health_score = None
        self._last_run_at = None
        self._next_run_at = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.domain = domain
        if name is not None:
            self.name = name
        if interval_seconds is not None:
            self.interval_seconds = interval_seconds
        self.enabled = enabled
        self.scheduling_enabled = scheduling_enabled
        if last_status is not None:
            self.last_status = last_status
        if health_score is not None:
            self.health_score = health_score
        if last_run_at is not None:
            self.last_run_at = last_run_at
        if next_run_at is not None:
            self.next_run_at = next_run_at
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this DomainMonitorDto.  # noqa: E501


        :return: The id of this DomainMonitorDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DomainMonitorDto.


        :param id: The id of this DomainMonitorDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this DomainMonitorDto.  # noqa: E501


        :return: The user_id of this DomainMonitorDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this DomainMonitorDto.


        :param user_id: The user_id of this DomainMonitorDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def domain(self):
        """Gets the domain of this DomainMonitorDto.  # noqa: E501


        :return: The domain of this DomainMonitorDto.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this DomainMonitorDto.


        :param domain: The domain of this DomainMonitorDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def name(self):
        """Gets the name of this DomainMonitorDto.  # noqa: E501


        :return: The name of this DomainMonitorDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DomainMonitorDto.


        :param name: The name of this DomainMonitorDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def interval_seconds(self):
        """Gets the interval_seconds of this DomainMonitorDto.  # noqa: E501


        :return: The interval_seconds of this DomainMonitorDto.  # noqa: E501
        :rtype: int
        """
        return self._interval_seconds

    @interval_seconds.setter
    def interval_seconds(self, interval_seconds):
        """Sets the interval_seconds of this DomainMonitorDto.


        :param interval_seconds: The interval_seconds of this DomainMonitorDto.  # noqa: E501
        :type: int
        """

        self._interval_seconds = interval_seconds

    @property
    def enabled(self):
        """Gets the enabled of this DomainMonitorDto.  # noqa: E501


        :return: The enabled of this DomainMonitorDto.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DomainMonitorDto.


        :param enabled: The enabled of this DomainMonitorDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `enabled`, must not be `None`")  # noqa: E501

        self._enabled = enabled

    @property
    def scheduling_enabled(self):
        """Gets the scheduling_enabled of this DomainMonitorDto.  # noqa: E501


        :return: The scheduling_enabled of this DomainMonitorDto.  # noqa: E501
        :rtype: bool
        """
        return self._scheduling_enabled

    @scheduling_enabled.setter
    def scheduling_enabled(self, scheduling_enabled):
        """Sets the scheduling_enabled of this DomainMonitorDto.


        :param scheduling_enabled: The scheduling_enabled of this DomainMonitorDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and scheduling_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `scheduling_enabled`, must not be `None`")  # noqa: E501

        self._scheduling_enabled = scheduling_enabled

    @property
    def last_status(self):
        """Gets the last_status of this DomainMonitorDto.  # noqa: E501


        :return: The last_status of this DomainMonitorDto.  # noqa: E501
        :rtype: str
        """
        return self._last_status

    @last_status.setter
    def last_status(self, last_status):
        """Sets the last_status of this DomainMonitorDto.


        :param last_status: The last_status of this DomainMonitorDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["HEALTHY", "DEGRADED", "CRITICAL", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and last_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `last_status` ({0}), must be one of {1}"  # noqa: E501
                .format(last_status, allowed_values)
            )

        self._last_status = last_status

    @property
    def health_score(self):
        """Gets the health_score of this DomainMonitorDto.  # noqa: E501


        :return: The health_score of this DomainMonitorDto.  # noqa: E501
        :rtype: int
        """
        return self._health_score

    @health_score.setter
    def health_score(self, health_score):
        """Sets the health_score of this DomainMonitorDto.


        :param health_score: The health_score of this DomainMonitorDto.  # noqa: E501
        :type: int
        """

        self._health_score = health_score

    @property
    def last_run_at(self):
        """Gets the last_run_at of this DomainMonitorDto.  # noqa: E501


        :return: The last_run_at of this DomainMonitorDto.  # noqa: E501
        :rtype: datetime
        """
        return self._last_run_at

    @last_run_at.setter
    def last_run_at(self, last_run_at):
        """Sets the last_run_at of this DomainMonitorDto.


        :param last_run_at: The last_run_at of this DomainMonitorDto.  # noqa: E501
        :type: datetime
        """

        self._last_run_at = last_run_at

    @property
    def next_run_at(self):
        """Gets the next_run_at of this DomainMonitorDto.  # noqa: E501


        :return: The next_run_at of this DomainMonitorDto.  # noqa: E501
        :rtype: datetime
        """
        return self._next_run_at

    @next_run_at.setter
    def next_run_at(self, next_run_at):
        """Sets the next_run_at of this DomainMonitorDto.


        :param next_run_at: The next_run_at of this DomainMonitorDto.  # noqa: E501
        :type: datetime
        """

        self._next_run_at = next_run_at

    @property
    def created_at(self):
        """Gets the created_at of this DomainMonitorDto.  # noqa: E501


        :return: The created_at of this DomainMonitorDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DomainMonitorDto.


        :param created_at: The created_at of this DomainMonitorDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DomainMonitorDto.  # noqa: E501


        :return: The updated_at of this DomainMonitorDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DomainMonitorDto.


        :param updated_at: The updated_at of this DomainMonitorDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainMonitorDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainMonitorDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.missed_sms_controller_api import MissedSmsControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestMissedSmsControllerApi(unittest.TestCase):
    """MissedSmsControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.missed_sms_controller_api.MissedSmsControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_missed_sms_messages(self):
        """Test case for get_all_missed_sms_messages

        Get all missed SMS messages in paginated format  # noqa: E501
        """
        pass

    def test_get_missed_sms_count(self):
        """Test case for get_missed_sms_count

        Get missed SMS count  # noqa: E501
        """
        pass

    def test_get_missed_sms_message(self):
        """Test case for get_missed_sms_message

        Get missed SMS content  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class GenerateBimiRecordOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'version': 'str',
        'logo_url': 'str',
        'vmc_url': 'str'
    }

    attribute_map = {
        'domain': 'domain',
        'version': 'version',
        'logo_url': 'logoUrl',
        'vmc_url': 'vmcUrl'
    }

    def __init__(self, domain=None, version=None, logo_url=None, vmc_url=None, local_vars_configuration=None):  # noqa: E501
        """GenerateBimiRecordOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._version = None
        self._logo_url = None
        self._vmc_url = None
        self.discriminator = None

        self.domain = domain
        self.version = version
        self.logo_url = logo_url
        if vmc_url is not None:
            self.vmc_url = vmc_url

    @property
    def domain(self):
        """Gets the domain of this GenerateBimiRecordOptions.  # noqa: E501


        :return: The domain of this GenerateBimiRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this GenerateBimiRecordOptions.


        :param domain: The domain of this GenerateBimiRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def version(self):
        """Gets the version of this GenerateBimiRecordOptions.  # noqa: E501


        :return: The version of this GenerateBimiRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this GenerateBimiRecordOptions.


        :param version: The version of this GenerateBimiRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501
        allowed_values = ["BIMI1"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and version not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `version` ({0}), must be one of {1}"  # noqa: E501
                .format(version, allowed_values)
            )

        self._version = version

    @property
    def logo_url(self):
        """Gets the logo_url of this GenerateBimiRecordOptions.  # noqa: E501


        :return: The logo_url of this GenerateBimiRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._logo_url

    @logo_url.setter
    def logo_url(self, logo_url):
        """Sets the logo_url of this GenerateBimiRecordOptions.


        :param logo_url: The logo_url of this GenerateBimiRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and logo_url is None:  # noqa: E501
            raise ValueError("Invalid value for `logo_url`, must not be `None`")  # noqa: E501

        self._logo_url = logo_url

    @property
    def vmc_url(self):
        """Gets the vmc_url of this GenerateBimiRecordOptions.  # noqa: E501


        :return: The vmc_url of this GenerateBimiRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._vmc_url

    @vmc_url.setter
    def vmc_url(self, vmc_url):
        """Sets the vmc_url of this GenerateBimiRecordOptions.


        :param vmc_url: The vmc_url of this GenerateBimiRecordOptions.  # noqa: E501
        :type: str
        """

        self._vmc_url = vmc_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerateBimiRecordOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GenerateBimiRecordOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class UpdateDeliverabilityTestOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'description': 'str',
        'start_at': 'datetime',
        'max_duration_seconds': 'int',
        'clear_max_duration': 'bool',
        'success_threshold_percent': 'float',
        'clear_success_threshold': 'bool',
        'expectations': 'list[DeliverabilityExpectation]'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'start_at': 'startAt',
        'max_duration_seconds': 'maxDurationSeconds',
        'clear_max_duration': 'clearMaxDuration',
        'success_threshold_percent': 'successThresholdPercent',
        'clear_success_threshold': 'clearSuccessThreshold',
        'expectations': 'expectations'
    }

    def __init__(self, name=None, description=None, start_at=None, max_duration_seconds=None, clear_max_duration=None, success_threshold_percent=None, clear_success_threshold=None, expectations=None, local_vars_configuration=None):  # noqa: E501
        """UpdateDeliverabilityTestOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._description = None
        self._start_at = None
        self._max_duration_seconds = None
        self._clear_max_duration = None
        self._success_threshold_percent = None
        self._clear_success_threshold = None
        self._expectations = None
        self.discriminator = None

        self.name = name
        self.description = description
        self.start_at = start_at
        self.max_duration_seconds = max_duration_seconds
        self.clear_max_duration = clear_max_duration
        self.success_threshold_percent = success_threshold_percent
        self.clear_success_threshold = clear_success_threshold
        self.expectations = expectations

    @property
    def name(self):
        """Gets the name of this UpdateDeliverabilityTestOptions.  # noqa: E501

        Optional updated name  # noqa: E501

        :return: The name of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateDeliverabilityTestOptions.

        Optional updated name  # noqa: E501

        :param name: The name of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this UpdateDeliverabilityTestOptions.  # noqa: E501

        Optional updated description  # noqa: E501

        :return: The description of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateDeliverabilityTestOptions.

        Optional updated description  # noqa: E501

        :param description: The description of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def start_at(self):
        """Gets the start_at of this UpdateDeliverabilityTestOptions.  # noqa: E501

        Optional updated receive-window start time. Only applied while test is not terminal.  # noqa: E501

        :return: The start_at of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._start_at

    @start_at.setter
    def start_at(self, start_at):
        """Sets the start_at of this UpdateDeliverabilityTestOptions.

        Optional updated receive-window start time. Only applied while test is not terminal.  # noqa: E501

        :param start_at: The start_at of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :type: datetime
        """

        self._start_at = start_at

    @property
    def max_duration_seconds(self):
        """Gets the max_duration_seconds of this UpdateDeliverabilityTestOptions.  # noqa: E501

        Optional updated timeout in seconds  # noqa: E501

        :return: The max_duration_seconds of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :rtype: int
        """
        return self._max_duration_seconds

    @max_duration_seconds.setter
    def max_duration_seconds(self, max_duration_seconds):
        """Sets the max_duration_seconds of this UpdateDeliverabilityTestOptions.

        Optional updated timeout in seconds  # noqa: E501

        :param max_duration_seconds: The max_duration_seconds of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_duration_seconds is not None and max_duration_seconds < 1):  # noqa: E501
            raise ValueError("Invalid value for `max_duration_seconds`, must be a value greater than or equal to `1`")  # noqa: E501

        self._max_duration_seconds = max_duration_seconds

    @property
    def clear_max_duration(self):
        """Gets the clear_max_duration of this UpdateDeliverabilityTestOptions.  # noqa: E501

        Set true to clear timeout. If true, maxDurationSeconds is ignored for this request.  # noqa: E501

        :return: The clear_max_duration of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._clear_max_duration

    @clear_max_duration.setter
    def clear_max_duration(self, clear_max_duration):
        """Sets the clear_max_duration of this UpdateDeliverabilityTestOptions.

        Set true to clear timeout. If true, maxDurationSeconds is ignored for this request.  # noqa: E501

        :param clear_max_duration: The clear_max_duration of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :type: bool
        """

        self._clear_max_duration = clear_max_duration

    @property
    def success_threshold_percent(self):
        """Gets the success_threshold_percent of this UpdateDeliverabilityTestOptions.  # noqa: E501

        Optional updated acceptable success threshold percentage (0,100].  # noqa: E501

        :return: The success_threshold_percent of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :rtype: float
        """
        return self._success_threshold_percent

    @success_threshold_percent.setter
    def success_threshold_percent(self, success_threshold_percent):
        """Sets the success_threshold_percent of this UpdateDeliverabilityTestOptions.

        Optional updated acceptable success threshold percentage (0,100].  # noqa: E501

        :param success_threshold_percent: The success_threshold_percent of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                success_threshold_percent is not None and success_threshold_percent > 100.0):  # noqa: E501
            raise ValueError("Invalid value for `success_threshold_percent`, must be a value less than or equal to `100.0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                success_threshold_percent is not None and success_threshold_percent <= 0.0):  # noqa: E501
            raise ValueError("Invalid value for `success_threshold_percent`, must be a value greater than `0.0`")  # noqa: E501

        self._success_threshold_percent = success_threshold_percent

    @property
    def clear_success_threshold(self):
        """Gets the clear_success_threshold of this UpdateDeliverabilityTestOptions.  # noqa: E501

        Set true to clear success threshold. If true, successThresholdPercent is ignored for this request.  # noqa: E501

        :return: The clear_success_threshold of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._clear_success_threshold

    @clear_success_threshold.setter
    def clear_success_threshold(self, clear_success_threshold):
        """Sets the clear_success_threshold of this UpdateDeliverabilityTestOptions.

        Set true to clear success threshold. If true, successThresholdPercent is ignored for this request.  # noqa: E501

        :param clear_success_threshold: The clear_success_threshold of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :type: bool
        """

        self._clear_success_threshold = clear_success_threshold

    @property
    def expectations(self):
        """Gets the expectations of this UpdateDeliverabilityTestOptions.  # noqa: E501

        Optional replacement expectations  # noqa: E501

        :return: The expectations of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :rtype: list[DeliverabilityExpectation]
        """
        return self._expectations

    @expectations.setter
    def expectations(self, expectations):
        """Sets the expectations of this UpdateDeliverabilityTestOptions.

        Optional replacement expectations  # noqa: E501

        :param expectations: The expectations of this UpdateDeliverabilityTestOptions.  # noqa: E501
        :type: list[DeliverabilityExpectation]
        """

        self._expectations = expectations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateDeliverabilityTestOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateDeliverabilityTestOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityAnalyticsSeriesDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'since': 'datetime',
        'before': 'datetime',
        'scope': 'str',
        'bucket': 'str',
        'summary': 'DeliverabilityAnalyticsSummaryDto',
        'runs': 'list[DeliverabilityAnalyticsRunDto]',
        'points': 'list[DeliverabilityAnalyticsSeriesPointDto]'
    }

    attribute_map = {
        'since': 'since',
        'before': 'before',
        'scope': 'scope',
        'bucket': 'bucket',
        'summary': 'summary',
        'runs': 'runs',
        'points': 'points'
    }

    def __init__(self, since=None, before=None, scope=None, bucket=None, summary=None, runs=None, points=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityAnalyticsSeriesDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._since = None
        self._before = None
        self._scope = None
        self._bucket = None
        self._summary = None
        self._runs = None
        self._points = None
        self.discriminator = None

        self.since = since
        self.before = before
        self.scope = scope
        self.bucket = bucket
        self.summary = summary
        self.runs = runs
        self.points = points

    @property
    def since(self):
        """Gets the since of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501


        :return: The since of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this DeliverabilityAnalyticsSeriesDto.


        :param since: The since of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and since is None:  # noqa: E501
            raise ValueError("Invalid value for `since`, must not be `None`")  # noqa: E501

        self._since = since

    @property
    def before(self):
        """Gets the before of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501


        :return: The before of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this DeliverabilityAnalyticsSeriesDto.


        :param before: The before of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and before is None:  # noqa: E501
            raise ValueError("Invalid value for `before`, must not be `None`")  # noqa: E501

        self._before = before

    @property
    def scope(self):
        """Gets the scope of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501


        :return: The scope of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this DeliverabilityAnalyticsSeriesDto.


        :param scope: The scope of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and scope not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    @property
    def bucket(self):
        """Gets the bucket of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501


        :return: The bucket of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this DeliverabilityAnalyticsSeriesDto.


        :param bucket: The bucket of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and bucket is None:  # noqa: E501
            raise ValueError("Invalid value for `bucket`, must not be `None`")  # noqa: E501
        allowed_values = ["HOUR", "DAY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and bucket not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `bucket` ({0}), must be one of {1}"  # noqa: E501
                .format(bucket, allowed_values)
            )

        self._bucket = bucket

    @property
    def summary(self):
        """Gets the summary of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501


        :return: The summary of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :rtype: DeliverabilityAnalyticsSummaryDto
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this DeliverabilityAnalyticsSeriesDto.


        :param summary: The summary of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :type: DeliverabilityAnalyticsSummaryDto
        """
        if self.local_vars_configuration.client_side_validation and summary is None:  # noqa: E501
            raise ValueError("Invalid value for `summary`, must not be `None`")  # noqa: E501

        self._summary = summary

    @property
    def runs(self):
        """Gets the runs of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501


        :return: The runs of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :rtype: list[DeliverabilityAnalyticsRunDto]
        """
        return self._runs

    @runs.setter
    def runs(self, runs):
        """Sets the runs of this DeliverabilityAnalyticsSeriesDto.


        :param runs: The runs of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :type: list[DeliverabilityAnalyticsRunDto]
        """
        if self.local_vars_configuration.client_side_validation and runs is None:  # noqa: E501
            raise ValueError("Invalid value for `runs`, must not be `None`")  # noqa: E501

        self._runs = runs

    @property
    def points(self):
        """Gets the points of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501


        :return: The points of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :rtype: list[DeliverabilityAnalyticsSeriesPointDto]
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this DeliverabilityAnalyticsSeriesDto.


        :param points: The points of this DeliverabilityAnalyticsSeriesDto.  # noqa: E501
        :type: list[DeliverabilityAnalyticsSeriesPointDto]
        """
        if self.local_vars_configuration.client_side_validation and points is None:  # noqa: E501
            raise ValueError("Invalid value for `points`, must not be `None`")  # noqa: E501

        self._points = points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityAnalyticsSeriesDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityAnalyticsSeriesDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DevicePreviewFeedbackDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'feedback_id': 'str',
        'user_id': 'str',
        'source': 'str',
        'category': 'str',
        'status': 'str',
        'rating': 'int',
        'run_id': 'str',
        'target_id': 'str',
        'screenshot_id': 'str',
        'provider': 'str',
        'title': 'str',
        'comment': 'str',
        'internal_note': 'str',
        'session_id': 'str',
        'live_view_url': 'str',
        'metadata': 'dict(str, str)',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'feedback_id': 'feedbackId',
        'user_id': 'userId',
        'source': 'source',
        'category': 'category',
        'status': 'status',
        'rating': 'rating',
        'run_id': 'runId',
        'target_id': 'targetId',
        'screenshot_id': 'screenshotId',
        'provider': 'provider',
        'title': 'title',
        'comment': 'comment',
        'internal_note': 'internalNote',
        'session_id': 'sessionId',
        'live_view_url': 'liveViewUrl',
        'metadata': 'metadata',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, feedback_id=None, user_id=None, source=None, category=None, status=None, rating=None, run_id=None, target_id=None, screenshot_id=None, provider=None, title=None, comment=None, internal_note=None, session_id=None, live_view_url=None, metadata=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DevicePreviewFeedbackDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._feedback_id = None
        self._user_id = None
        self._source = None
        self._category = None
        self._status = None
        self._rating = None
        self._run_id = None
        self._target_id = None
        self._screenshot_id = None
        self._provider = None
        self._title = None
        self._comment = None
        self._internal_note = None
        self._session_id = None
        self._live_view_url = None
        self._metadata = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.feedback_id = feedback_id
        self.user_id = user_id
        self.source = source
        self.category = category
        self.status = status
        if rating is not None:
            self.rating = rating
        if run_id is not None:
            self.run_id = run_id
        if target_id is not None:
            self.target_id = target_id
        if screenshot_id is not None:
            self.screenshot_id = screenshot_id
        if provider is not None:
            self.provider = provider
        if title is not None:
            self.title = title
        if comment is not None:
            self.comment = comment
        if internal_note is not None:
            self.internal_note = internal_note
        if session_id is not None:
            self.session_id = session_id
        if live_view_url is not None:
            self.live_view_url = live_view_url
        if metadata is not None:
            self.metadata = metadata
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def feedback_id(self):
        """Gets the feedback_id of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The feedback_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._feedback_id

    @feedback_id.setter
    def feedback_id(self, feedback_id):
        """Sets the feedback_id of this DevicePreviewFeedbackDto.


        :param feedback_id: The feedback_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and feedback_id is None:  # noqa: E501
            raise ValueError("Invalid value for `feedback_id`, must not be `None`")  # noqa: E501

        self._feedback_id = feedback_id

    @property
    def user_id(self):
        """Gets the user_id of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The user_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this DevicePreviewFeedbackDto.


        :param user_id: The user_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def source(self):
        """Gets the source of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The source of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this DevicePreviewFeedbackDto.


        :param source: The source of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source is None:  # noqa: E501
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501
        allowed_values = ["API_SERVICE", "LAB_USER", "END_USER", "SYSTEM"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and source not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `source` ({0}), must be one of {1}"  # noqa: E501
                .format(source, allowed_values)
            )

        self._source = source

    @property
    def category(self):
        """Gets the category of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The category of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this DevicePreviewFeedbackDto.


        :param category: The category of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and category is None:  # noqa: E501
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501
        allowed_values = ["GENERAL", "RUN_QUALITY", "SCREENSHOT_QUALITY", "PROVIDER_ISSUE", "BUG_REPORT", "FEATURE_REQUEST", "NOTE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and category not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}"  # noqa: E501
                .format(category, allowed_values)
            )

        self._category = category

    @property
    def status(self):
        """Gets the status of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The status of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DevicePreviewFeedbackDto.


        :param status: The status of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["OPEN", "ACKNOWLEDGED", "RESOLVED", "DISMISSED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def rating(self):
        """Gets the rating of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The rating of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: int
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this DevicePreviewFeedbackDto.


        :param rating: The rating of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: int
        """

        self._rating = rating

    @property
    def run_id(self):
        """Gets the run_id of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The run_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this DevicePreviewFeedbackDto.


        :param run_id: The run_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """

        self._run_id = run_id

    @property
    def target_id(self):
        """Gets the target_id of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The target_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this DevicePreviewFeedbackDto.


        :param target_id: The target_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    @property
    def screenshot_id(self):
        """Gets the screenshot_id of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The screenshot_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._screenshot_id

    @screenshot_id.setter
    def screenshot_id(self, screenshot_id):
        """Sets the screenshot_id of this DevicePreviewFeedbackDto.


        :param screenshot_id: The screenshot_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """

        self._screenshot_id = screenshot_id

    @property
    def provider(self):
        """Gets the provider of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The provider of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this DevicePreviewFeedbackDto.


        :param provider: The provider of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["GMAIL", "OUTLOOK", "YAHOO"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and provider not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `provider` ({0}), must be one of {1}"  # noqa: E501
                .format(provider, allowed_values)
            )

        self._provider = provider

    @property
    def title(self):
        """Gets the title of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The title of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this DevicePreviewFeedbackDto.


        :param title: The title of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def comment(self):
        """Gets the comment of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The comment of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this DevicePreviewFeedbackDto.


        :param comment: The comment of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def internal_note(self):
        """Gets the internal_note of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The internal_note of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._internal_note

    @internal_note.setter
    def internal_note(self, internal_note):
        """Sets the internal_note of this DevicePreviewFeedbackDto.


        :param internal_note: The internal_note of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """

        self._internal_note = internal_note

    @property
    def session_id(self):
        """Gets the session_id of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The session_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this DevicePreviewFeedbackDto.


        :param session_id: The session_id of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """

        self._session_id = session_id

    @property
    def live_view_url(self):
        """Gets the live_view_url of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The live_view_url of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: str
        """
        return self._live_view_url

    @live_view_url.setter
    def live_view_url(self, live_view_url):
        """Sets the live_view_url of this DevicePreviewFeedbackDto.


        :param live_view_url: The live_view_url of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: str
        """

        self._live_view_url = live_view_url

    @property
    def metadata(self):
        """Gets the metadata of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The metadata of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this DevicePreviewFeedbackDto.


        :param metadata: The metadata of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def created_at(self):
        """Gets the created_at of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The created_at of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DevicePreviewFeedbackDto.


        :param created_at: The created_at of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DevicePreviewFeedbackDto.  # noqa: E501


        :return: The updated_at of this DevicePreviewFeedbackDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DevicePreviewFeedbackDto.


        :param updated_at: The updated_at of this DevicePreviewFeedbackDto.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicePreviewFeedbackDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DevicePreviewFeedbackDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailIntelligenceScoreBreakdownDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'randomness_penalty': 'int',
        'free_provider_penalty': 'int',
        'https_website_penalty': 'int',
        'dns_penalty': 'int',
        'domain_age_penalty': 'int',
        'email_validation_penalty': 'int',
        'total_penalty': 'int'
    }

    attribute_map = {
        'randomness_penalty': 'randomnessPenalty',
        'free_provider_penalty': 'freeProviderPenalty',
        'https_website_penalty': 'httpsWebsitePenalty',
        'dns_penalty': 'dnsPenalty',
        'domain_age_penalty': 'domainAgePenalty',
        'email_validation_penalty': 'emailValidationPenalty',
        'total_penalty': 'totalPenalty'
    }

    def __init__(self, randomness_penalty=None, free_provider_penalty=None, https_website_penalty=None, dns_penalty=None, domain_age_penalty=None, email_validation_penalty=None, total_penalty=None, local_vars_configuration=None):  # noqa: E501
        """EmailIntelligenceScoreBreakdownDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._randomness_penalty = None
        self._free_provider_penalty = None
        self._https_website_penalty = None
        self._dns_penalty = None
        self._domain_age_penalty = None
        self._email_validation_penalty = None
        self._total_penalty = None
        self.discriminator = None

        self.randomness_penalty = randomness_penalty
        self.free_provider_penalty = free_provider_penalty
        self.https_website_penalty = https_website_penalty
        self.dns_penalty = dns_penalty
        self.domain_age_penalty = domain_age_penalty
        self.email_validation_penalty = email_validation_penalty
        self.total_penalty = total_penalty

    @property
    def randomness_penalty(self):
        """Gets the randomness_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501


        :return: The randomness_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :rtype: int
        """
        return self._randomness_penalty

    @randomness_penalty.setter
    def randomness_penalty(self, randomness_penalty):
        """Sets the randomness_penalty of this EmailIntelligenceScoreBreakdownDto.


        :param randomness_penalty: The randomness_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and randomness_penalty is None:  # noqa: E501
            raise ValueError("Invalid value for `randomness_penalty`, must not be `None`")  # noqa: E501

        self._randomness_penalty = randomness_penalty

    @property
    def free_provider_penalty(self):
        """Gets the free_provider_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501


        :return: The free_provider_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :rtype: int
        """
        return self._free_provider_penalty

    @free_provider_penalty.setter
    def free_provider_penalty(self, free_provider_penalty):
        """Sets the free_provider_penalty of this EmailIntelligenceScoreBreakdownDto.


        :param free_provider_penalty: The free_provider_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and free_provider_penalty is None:  # noqa: E501
            raise ValueError("Invalid value for `free_provider_penalty`, must not be `None`")  # noqa: E501

        self._free_provider_penalty = free_provider_penalty

    @property
    def https_website_penalty(self):
        """Gets the https_website_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501


        :return: The https_website_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :rtype: int
        """
        return self._https_website_penalty

    @https_website_penalty.setter
    def https_website_penalty(self, https_website_penalty):
        """Sets the https_website_penalty of this EmailIntelligenceScoreBreakdownDto.


        :param https_website_penalty: The https_website_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and https_website_penalty is None:  # noqa: E501
            raise ValueError("Invalid value for `https_website_penalty`, must not be `None`")  # noqa: E501

        self._https_website_penalty = https_website_penalty

    @property
    def dns_penalty(self):
        """Gets the dns_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501


        :return: The dns_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :rtype: int
        """
        return self._dns_penalty

    @dns_penalty.setter
    def dns_penalty(self, dns_penalty):
        """Sets the dns_penalty of this EmailIntelligenceScoreBreakdownDto.


        :param dns_penalty: The dns_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and dns_penalty is None:  # noqa: E501
            raise ValueError("Invalid value for `dns_penalty`, must not be `None`")  # noqa: E501

        self._dns_penalty = dns_penalty

    @property
    def domain_age_penalty(self):
        """Gets the domain_age_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501


        :return: The domain_age_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :rtype: int
        """
        return self._domain_age_penalty

    @domain_age_penalty.setter
    def domain_age_penalty(self, domain_age_penalty):
        """Sets the domain_age_penalty of this EmailIntelligenceScoreBreakdownDto.


        :param domain_age_penalty: The domain_age_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and domain_age_penalty is None:  # noqa: E501
            raise ValueError("Invalid value for `domain_age_penalty`, must not be `None`")  # noqa: E501

        self._domain_age_penalty = domain_age_penalty

    @property
    def email_validation_penalty(self):
        """Gets the email_validation_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501


        :return: The email_validation_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :rtype: int
        """
        return self._email_validation_penalty

    @email_validation_penalty.setter
    def email_validation_penalty(self, email_validation_penalty):
        """Sets the email_validation_penalty of this EmailIntelligenceScoreBreakdownDto.


        :param email_validation_penalty: The email_validation_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and email_validation_penalty is None:  # noqa: E501
            raise ValueError("Invalid value for `email_validation_penalty`, must not be `None`")  # noqa: E501

        self._email_validation_penalty = email_validation_penalty

    @property
    def total_penalty(self):
        """Gets the total_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501


        :return: The total_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :rtype: int
        """
        return self._total_penalty

    @total_penalty.setter
    def total_penalty(self, total_penalty):
        """Sets the total_penalty of this EmailIntelligenceScoreBreakdownDto.


        :param total_penalty: The total_penalty of this EmailIntelligenceScoreBreakdownDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_penalty is None:  # noqa: E501
            raise ValueError("Invalid value for `total_penalty`, must not be `None`")  # noqa: E501

        self._total_penalty = total_penalty

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailIntelligenceScoreBreakdownDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailIntelligenceScoreBreakdownDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateCampaignProbeOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'enabled': 'bool',
        'interval_seconds': 'int',
        'scheduling_enabled': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'enabled': 'enabled',
        'interval_seconds': 'intervalSeconds',
        'scheduling_enabled': 'schedulingEnabled'
    }

    def __init__(self, name=None, enabled=None, interval_seconds=None, scheduling_enabled=None, local_vars_configuration=None):  # noqa: E501
        """CreateCampaignProbeOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._enabled = None
        self._interval_seconds = None
        self._scheduling_enabled = None
        self.discriminator = None

        self.name = name
        self.enabled = enabled
        self.interval_seconds = interval_seconds
        self.scheduling_enabled = scheduling_enabled

    @property
    def name(self):
        """Gets the name of this CreateCampaignProbeOptions.  # noqa: E501

        Optional display name  # noqa: E501

        :return: The name of this CreateCampaignProbeOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateCampaignProbeOptions.

        Optional display name  # noqa: E501

        :param name: The name of this CreateCampaignProbeOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 200):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `200`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def enabled(self):
        """Gets the enabled of this CreateCampaignProbeOptions.  # noqa: E501

        Whether SES monitor ingestion is enabled for this probe  # noqa: E501

        :return: The enabled of this CreateCampaignProbeOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CreateCampaignProbeOptions.

        Whether SES monitor ingestion is enabled for this probe  # noqa: E501

        :param enabled: The enabled of this CreateCampaignProbeOptions.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def interval_seconds(self):
        """Gets the interval_seconds of this CreateCampaignProbeOptions.  # noqa: E501

        Scheduled run interval in seconds  # noqa: E501

        :return: The interval_seconds of this CreateCampaignProbeOptions.  # noqa: E501
        :rtype: int
        """
        return self._interval_seconds

    @interval_seconds.setter
    def interval_seconds(self, interval_seconds):
        """Sets the interval_seconds of this CreateCampaignProbeOptions.

        Scheduled run interval in seconds  # noqa: E501

        :param interval_seconds: The interval_seconds of this CreateCampaignProbeOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                interval_seconds is not None and interval_seconds > 604800):  # noqa: E501
            raise ValueError("Invalid value for `interval_seconds`, must be a value less than or equal to `604800`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                interval_seconds is not None and interval_seconds < 60):  # noqa: E501
            raise ValueError("Invalid value for `interval_seconds`, must be a value greater than or equal to `60`")  # noqa: E501

        self._interval_seconds = interval_seconds

    @property
    def scheduling_enabled(self):
        """Gets the scheduling_enabled of this CreateCampaignProbeOptions.  # noqa: E501

        Whether scheduled campaign probe runs are enabled. Direct run-now remains available.  # noqa: E501

        :return: The scheduling_enabled of this CreateCampaignProbeOptions.  # noqa: E501
        :rtype: bool
        """
        return self._scheduling_enabled

    @scheduling_enabled.setter
    def scheduling_enabled(self, scheduling_enabled):
        """Sets the scheduling_enabled of this CreateCampaignProbeOptions.

        Whether scheduled campaign probe runs are enabled. Direct run-now remains available.  # noqa: E501

        :param scheduling_enabled: The scheduling_enabled of this CreateCampaignProbeOptions.  # noqa: E501
        :type: bool
        """

        self._scheduling_enabled = scheduling_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateCampaignProbeOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateCampaignProbeOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class InboxAutomationMatchOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'operator': 'str',
        'matches': 'list[InboxAutomationMatchOption]',
        'groups': 'list[InboxAutomationMatchOptions]'
    }

    attribute_map = {
        'operator': 'operator',
        'matches': 'matches',
        'groups': 'groups'
    }

    def __init__(self, operator=None, matches=None, groups=None, local_vars_configuration=None):  # noqa: E501
        """InboxAutomationMatchOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._operator = None
        self._matches = None
        self._groups = None
        self.discriminator = None

        self.operator = operator
        self.matches = matches
        self.groups = groups

    @property
    def operator(self):
        """Gets the operator of this InboxAutomationMatchOptions.  # noqa: E501

        Boolean operator used to combine inbox automation match rules.  # noqa: E501

        :return: The operator of this InboxAutomationMatchOptions.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this InboxAutomationMatchOptions.

        Boolean operator used to combine inbox automation match rules.  # noqa: E501

        :param operator: The operator of this InboxAutomationMatchOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501
        allowed_values = ["AND", "OR"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operator not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `operator` ({0}), must be one of {1}"  # noqa: E501
                .format(operator, allowed_values)
            )

        self._operator = operator

    @property
    def matches(self):
        """Gets the matches of this InboxAutomationMatchOptions.  # noqa: E501

        Leaf match rules in this group.  # noqa: E501

        :return: The matches of this InboxAutomationMatchOptions.  # noqa: E501
        :rtype: list[InboxAutomationMatchOption]
        """
        return self._matches

    @matches.setter
    def matches(self, matches):
        """Sets the matches of this InboxAutomationMatchOptions.

        Leaf match rules in this group.  # noqa: E501

        :param matches: The matches of this InboxAutomationMatchOptions.  # noqa: E501
        :type: list[InboxAutomationMatchOption]
        """

        self._matches = matches

    @property
    def groups(self):
        """Gets the groups of this InboxAutomationMatchOptions.  # noqa: E501

        Nested child groups.  # noqa: E501

        :return: The groups of this InboxAutomationMatchOptions.  # noqa: E501
        :rtype: list[InboxAutomationMatchOptions]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """Sets the groups of this InboxAutomationMatchOptions.

        Nested child groups.  # noqa: E501

        :param groups: The groups of this InboxAutomationMatchOptions.  # noqa: E501
        :type: list[InboxAutomationMatchOptions]
        """

        self._groups = groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InboxAutomationMatchOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InboxAutomationMatchOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CodeCandidate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'str',
        'confidence': 'float',
        'method': 'str',
        'source': 'str',
        'context': 'str'
    }

    attribute_map = {
        'code': 'code',
        'confidence': 'confidence',
        'method': 'method',
        'source': 'source',
        'context': 'context'
    }

    def __init__(self, code=None, confidence=None, method=None, source=None, context=None, local_vars_configuration=None):  # noqa: E501
        """CodeCandidate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._confidence = None
        self._method = None
        self._source = None
        self._context = None
        self.discriminator = None

        self.code = code
        self.confidence = confidence
        self.method = method
        self.source = source
        self.context = context

    @property
    def code(self):
        """Gets the code of this CodeCandidate.  # noqa: E501

        Extracted code value  # noqa: E501

        :return: The code of this CodeCandidate.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this CodeCandidate.

        Extracted code value  # noqa: E501

        :param code: The code of this CodeCandidate.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and code is None:  # noqa: E501
            raise ValueError("Invalid value for `code`, must not be `None`")  # noqa: E501

        self._code = code

    @property
    def confidence(self):
        """Gets the confidence of this CodeCandidate.  # noqa: E501

        Relative confidence score from 0 to 1  # noqa: E501

        :return: The confidence of this CodeCandidate.  # noqa: E501
        :rtype: float
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """Sets the confidence of this CodeCandidate.

        Relative confidence score from 0 to 1  # noqa: E501

        :param confidence: The confidence of this CodeCandidate.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and confidence is None:  # noqa: E501
            raise ValueError("Invalid value for `confidence`, must not be `None`")  # noqa: E501

        self._confidence = confidence

    @property
    def method(self):
        """Gets the method of this CodeCandidate.  # noqa: E501

        Extraction strategy for verification codes. Unsupported strategies may fall back when allowFallback is true.  # noqa: E501

        :return: The method of this CodeCandidate.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this CodeCandidate.

        Extraction strategy for verification codes. Unsupported strategies may fall back when allowFallback is true.  # noqa: E501

        :param method: The method of this CodeCandidate.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and method is None:  # noqa: E501
            raise ValueError("Invalid value for `method`, must not be `None`")  # noqa: E501
        allowed_values = ["AUTO", "PATTERN", "LLM", "OCR", "OCR_THEN_LLM"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and method not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                .format(method, allowed_values)
            )

        self._method = method

    @property
    def source(self):
        """Gets the source of this CodeCandidate.  # noqa: E501

        Source fragment used for extraction, for example RAW_TEXT_PART or SMS_BODY  # noqa: E501

        :return: The source of this CodeCandidate.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this CodeCandidate.

        Source fragment used for extraction, for example RAW_TEXT_PART or SMS_BODY  # noqa: E501

        :param source: The source of this CodeCandidate.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source is None:  # noqa: E501
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501

        self._source = source

    @property
    def context(self):
        """Gets the context of this CodeCandidate.  # noqa: E501

        Nearby text context useful for debugging extraction decisions  # noqa: E501

        :return: The context of this CodeCandidate.  # noqa: E501
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this CodeCandidate.

        Nearby text context useful for debugging extraction decisions  # noqa: E501

        :param context: The context of this CodeCandidate.  # noqa: E501
        :type: str
        """

        self._context = context

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodeCandidate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CodeCandidate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class SearchAvailablePhoneNumbersOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'phone_country': 'str',
        'phone_variant': 'str',
        'quality_filter': 'str',
        'line_type': 'str',
        'carrier_name': 'str',
        'mobile_country_code': 'str',
        'mobile_network_code': 'str',
        'provider_labels': 'list[str]',
        'limit': 'int'
    }

    attribute_map = {
        'phone_country': 'phoneCountry',
        'phone_variant': 'phoneVariant',
        'quality_filter': 'qualityFilter',
        'line_type': 'lineType',
        'carrier_name': 'carrierName',
        'mobile_country_code': 'mobileCountryCode',
        'mobile_network_code': 'mobileNetworkCode',
        'provider_labels': 'providerLabels',
        'limit': 'limit'
    }

    def __init__(self, phone_country=None, phone_variant=None, quality_filter=None, line_type=None, carrier_name=None, mobile_country_code=None, mobile_network_code=None, provider_labels=None, limit=None, local_vars_configuration=None):  # noqa: E501
        """SearchAvailablePhoneNumbersOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._phone_country = None
        self._phone_variant = None
        self._quality_filter = None
        self._line_type = None
        self._carrier_name = None
        self._mobile_country_code = None
        self._mobile_network_code = None
        self._provider_labels = None
        self._limit = None
        self.discriminator = None

        self.phone_country = phone_country
        self.phone_variant = phone_variant
        self.quality_filter = quality_filter
        self.line_type = line_type
        self.carrier_name = carrier_name
        self.mobile_country_code = mobile_country_code
        self.mobile_network_code = mobile_network_code
        self.provider_labels = provider_labels
        self.limit = limit

    @property
    def phone_country(self):
        """Gets the phone_country of this SearchAvailablePhoneNumbersOptions.  # noqa: E501


        :return: The phone_country of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this SearchAvailablePhoneNumbersOptions.


        :param phone_country: The phone_country of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_variant(self):
        """Gets the phone_variant of this SearchAvailablePhoneNumbersOptions.  # noqa: E501


        :return: The phone_variant of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :rtype: str
        """
        return self._phone_variant

    @phone_variant.setter
    def phone_variant(self, phone_variant):
        """Sets the phone_variant of this SearchAvailablePhoneNumbersOptions.


        :param phone_variant: The phone_variant of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"LOCAL", "MOBILE", "TOLL_FREE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_variant not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_variant` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_variant, allowed_values)
            )

        self._phone_variant = phone_variant

    @property
    def quality_filter(self):
        """Gets the quality_filter of this SearchAvailablePhoneNumbersOptions.  # noqa: E501

        Quality filter for advanced phone provisioning search  # noqa: E501

        :return: The quality_filter of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :rtype: str
        """
        return self._quality_filter

    @quality_filter.setter
    def quality_filter(self, quality_filter):
        """Sets the quality_filter of this SearchAvailablePhoneNumbersOptions.

        Quality filter for advanced phone provisioning search  # noqa: E501

        :param quality_filter: The quality_filter of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"OTP", "NON_VOIP", "MOBILE_ONLY", "ANY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and quality_filter not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `quality_filter` ({0}), must be one of {1}"  # noqa: E501
                .format(quality_filter, allowed_values)
            )

        self._quality_filter = quality_filter

    @property
    def line_type(self):
        """Gets the line_type of this SearchAvailablePhoneNumbersOptions.  # noqa: E501


        :return: The line_type of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :rtype: str
        """
        return self._line_type

    @line_type.setter
    def line_type(self, line_type):
        """Sets the line_type of this SearchAvailablePhoneNumbersOptions.


        :param line_type: The line_type of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :type: str
        """

        self._line_type = line_type

    @property
    def carrier_name(self):
        """Gets the carrier_name of this SearchAvailablePhoneNumbersOptions.  # noqa: E501


        :return: The carrier_name of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :rtype: str
        """
        return self._carrier_name

    @carrier_name.setter
    def carrier_name(self, carrier_name):
        """Sets the carrier_name of this SearchAvailablePhoneNumbersOptions.


        :param carrier_name: The carrier_name of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :type: str
        """

        self._carrier_name = carrier_name

    @property
    def mobile_country_code(self):
        """Gets the mobile_country_code of this SearchAvailablePhoneNumbersOptions.  # noqa: E501


        :return: The mobile_country_code of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :rtype: str
        """
        return self._mobile_country_code

    @mobile_country_code.setter
    def mobile_country_code(self, mobile_country_code):
        """Sets the mobile_country_code of this SearchAvailablePhoneNumbersOptions.


        :param mobile_country_code: The mobile_country_code of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :type: str
        """

        self._mobile_country_code = mobile_country_code

    @property
    def mobile_network_code(self):
        """Gets the mobile_network_code of this SearchAvailablePhoneNumbersOptions.  # noqa: E501


        :return: The mobile_network_code of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :rtype: str
        """
        return self._mobile_network_code

    @mobile_network_code.setter
    def mobile_network_code(self, mobile_network_code):
        """Sets the mobile_network_code of this SearchAvailablePhoneNumbersOptions.


        :param mobile_network_code: The mobile_network_code of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :type: str
        """

        self._mobile_network_code = mobile_network_code

    @property
    def provider_labels(self):
        """Gets the provider_labels of this SearchAvailablePhoneNumbersOptions.  # noqa: E501


        :return: The provider_labels of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._provider_labels

    @provider_labels.setter
    def provider_labels(self, provider_labels):
        """Sets the provider_labels of this SearchAvailablePhoneNumbersOptions.


        :param provider_labels: The provider_labels of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :type: list[str]
        """

        self._provider_labels = provider_labels

    @property
    def limit(self):
        """Gets the limit of this SearchAvailablePhoneNumbersOptions.  # noqa: E501


        :return: The limit of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this SearchAvailablePhoneNumbersOptions.


        :param limit: The limit of this SearchAvailablePhoneNumbersOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                limit is not None and limit > 100):  # noqa: E501
            raise ValueError("Invalid value for `limit`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                limit is not None and limit < 1):  # noqa: E501
            raise ValueError("Invalid value for `limit`, must be a value greater than or equal to `1`")  # noqa: E501

        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchAvailablePhoneNumbersOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchAvailablePhoneNumbersOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class WebhookDeliveryStatusPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message_id': 'str',
        'webhook_id': 'str',
        'event_name': 'str',
        'webhook_name': 'str',
        'id': 'str',
        'user_id': 'str',
        'sent_id': 'str',
        'remote_mta_ip': 'str',
        'inbox_id': 'str',
        'reporting_mta': 'str',
        'recipients': 'list[str]',
        'smtp_response': 'str',
        'smtp_status_code': 'int',
        'processing_time_millis': 'int',
        'received': 'datetime',
        'subject': 'str'
    }

    attribute_map = {
        'message_id': 'messageId',
        'webhook_id': 'webhookId',
        'event_name': 'eventName',
        'webhook_name': 'webhookName',
        'id': 'id',
        'user_id': 'userId',
        'sent_id': 'sentId',
        'remote_mta_ip': 'remoteMtaIp',
        'inbox_id': 'inboxId',
        'reporting_mta': 'reportingMta',
        'recipients': 'recipients',
        'smtp_response': 'smtpResponse',
        'smtp_status_code': 'smtpStatusCode',
        'processing_time_millis': 'processingTimeMillis',
        'received': 'received',
        'subject': 'subject'
    }

    def __init__(self, message_id=None, webhook_id=None, event_name=None, webhook_name=None, id=None, user_id=None, sent_id=None, remote_mta_ip=None, inbox_id=None, reporting_mta=None, recipients=None, smtp_response=None, smtp_status_code=None, processing_time_millis=None, received=None, subject=None, local_vars_configuration=None):  # noqa: E501
        """WebhookDeliveryStatusPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._message_id = None
        self._webhook_id = None
        self._event_name = None
        self._webhook_name = None
        self._id = None
        self._user_id = None
        self._sent_id = None
        self._remote_mta_ip = None
        self._inbox_id = None
        self._reporting_mta = None
        self._recipients = None
        self._smtp_response = None
        self._smtp_status_code = None
        self._processing_time_millis = None
        self._received = None
        self._subject = None
        self.discriminator = None

        self.message_id = message_id
        self.webhook_id = webhook_id
        self.event_name = event_name
        self.webhook_name = webhook_name
        self.id = id
        self.user_id = user_id
        self.sent_id = sent_id
        self.remote_mta_ip = remote_mta_ip
        self.inbox_id = inbox_id
        self.reporting_mta = reporting_mta
        self.recipients = recipients
        self.smtp_response = smtp_response
        self.smtp_status_code = smtp_status_code
        self.processing_time_millis = processing_time_millis
        self.received = received
        self.subject = subject

    @property
    def message_id(self):
        """Gets the message_id of this WebhookDeliveryStatusPayload.  # noqa: E501

        Idempotent message ID. Store this ID locally or in a database to prevent message duplication.  # noqa: E501

        :return: The message_id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this WebhookDeliveryStatusPayload.

        Idempotent message ID. Store this ID locally or in a database to prevent message duplication.  # noqa: E501

        :param message_id: The message_id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and message_id is None:  # noqa: E501
            raise ValueError("Invalid value for `message_id`, must not be `None`")  # noqa: E501

        self._message_id = message_id

    @property
    def webhook_id(self):
        """Gets the webhook_id of this WebhookDeliveryStatusPayload.  # noqa: E501

        ID of webhook entity being triggered  # noqa: E501

        :return: The webhook_id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._webhook_id

    @webhook_id.setter
    def webhook_id(self, webhook_id):
        """Sets the webhook_id of this WebhookDeliveryStatusPayload.

        ID of webhook entity being triggered  # noqa: E501

        :param webhook_id: The webhook_id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and webhook_id is None:  # noqa: E501
            raise ValueError("Invalid value for `webhook_id`, must not be `None`")  # noqa: E501

        self._webhook_id = webhook_id

    @property
    def event_name(self):
        """Gets the event_name of this WebhookDeliveryStatusPayload.  # noqa: E501

        Name of the event type webhook is being triggered for.  # noqa: E501

        :return: The event_name of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this WebhookDeliveryStatusPayload.

        Name of the event type webhook is being triggered for.  # noqa: E501

        :param event_name: The event_name of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event_name is None:  # noqa: E501
            raise ValueError("Invalid value for `event_name`, must not be `None`")  # noqa: E501
        allowed_values = ["EMAIL_RECEIVED", "NEW_AI_TRANSFORM_RESULT", "NEW_EMAIL", "NEW_CONTACT", "NEW_ATTACHMENT", "EMAIL_OPENED", "EMAIL_READ", "DELIVERY_STATUS", "BOUNCE", "BOUNCE_RECIPIENT", "NEW_SMS", "NEW_GUEST_USER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_name not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_name` ({0}), must be one of {1}"  # noqa: E501
                .format(event_name, allowed_values)
            )

        self._event_name = event_name

    @property
    def webhook_name(self):
        """Gets the webhook_name of this WebhookDeliveryStatusPayload.  # noqa: E501

        Name of the webhook being triggered  # noqa: E501

        :return: The webhook_name of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._webhook_name

    @webhook_name.setter
    def webhook_name(self, webhook_name):
        """Sets the webhook_name of this WebhookDeliveryStatusPayload.

        Name of the webhook being triggered  # noqa: E501

        :param webhook_name: The webhook_name of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """

        self._webhook_name = webhook_name

    @property
    def id(self):
        """Gets the id of this WebhookDeliveryStatusPayload.  # noqa: E501

        ID of delivery status  # noqa: E501

        :return: The id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebhookDeliveryStatusPayload.

        ID of delivery status  # noqa: E501

        :param id: The id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this WebhookDeliveryStatusPayload.  # noqa: E501

        User ID of event  # noqa: E501

        :return: The user_id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this WebhookDeliveryStatusPayload.

        User ID of event  # noqa: E501

        :param user_id: The user_id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def sent_id(self):
        """Gets the sent_id of this WebhookDeliveryStatusPayload.  # noqa: E501

        ID of sent email  # noqa: E501

        :return: The sent_id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._sent_id

    @sent_id.setter
    def sent_id(self, sent_id):
        """Sets the sent_id of this WebhookDeliveryStatusPayload.

        ID of sent email  # noqa: E501

        :param sent_id: The sent_id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """

        self._sent_id = sent_id

    @property
    def remote_mta_ip(self):
        """Gets the remote_mta_ip of this WebhookDeliveryStatusPayload.  # noqa: E501

        IP address of the remote Mail Transfer Agent  # noqa: E501

        :return: The remote_mta_ip of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._remote_mta_ip

    @remote_mta_ip.setter
    def remote_mta_ip(self, remote_mta_ip):
        """Sets the remote_mta_ip of this WebhookDeliveryStatusPayload.

        IP address of the remote Mail Transfer Agent  # noqa: E501

        :param remote_mta_ip: The remote_mta_ip of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """

        self._remote_mta_ip = remote_mta_ip

    @property
    def inbox_id(self):
        """Gets the inbox_id of this WebhookDeliveryStatusPayload.  # noqa: E501

        Id of the inbox  # noqa: E501

        :return: The inbox_id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this WebhookDeliveryStatusPayload.

        Id of the inbox  # noqa: E501

        :param inbox_id: The inbox_id of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def reporting_mta(self):
        """Gets the reporting_mta of this WebhookDeliveryStatusPayload.  # noqa: E501

        Mail Transfer Agent reporting delivery status  # noqa: E501

        :return: The reporting_mta of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._reporting_mta

    @reporting_mta.setter
    def reporting_mta(self, reporting_mta):
        """Sets the reporting_mta of this WebhookDeliveryStatusPayload.

        Mail Transfer Agent reporting delivery status  # noqa: E501

        :param reporting_mta: The reporting_mta of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """

        self._reporting_mta = reporting_mta

    @property
    def recipients(self):
        """Gets the recipients of this WebhookDeliveryStatusPayload.  # noqa: E501

        Recipients for delivery  # noqa: E501

        :return: The recipients of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: list[str]
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this WebhookDeliveryStatusPayload.

        Recipients for delivery  # noqa: E501

        :param recipients: The recipients of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: list[str]
        """

        self._recipients = recipients

    @property
    def smtp_response(self):
        """Gets the smtp_response of this WebhookDeliveryStatusPayload.  # noqa: E501

        SMTP server response message  # noqa: E501

        :return: The smtp_response of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._smtp_response

    @smtp_response.setter
    def smtp_response(self, smtp_response):
        """Sets the smtp_response of this WebhookDeliveryStatusPayload.

        SMTP server response message  # noqa: E501

        :param smtp_response: The smtp_response of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """

        self._smtp_response = smtp_response

    @property
    def smtp_status_code(self):
        """Gets the smtp_status_code of this WebhookDeliveryStatusPayload.  # noqa: E501

        SMTP server status  # noqa: E501

        :return: The smtp_status_code of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: int
        """
        return self._smtp_status_code

    @smtp_status_code.setter
    def smtp_status_code(self, smtp_status_code):
        """Sets the smtp_status_code of this WebhookDeliveryStatusPayload.

        SMTP server status  # noqa: E501

        :param smtp_status_code: The smtp_status_code of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: int
        """

        self._smtp_status_code = smtp_status_code

    @property
    def processing_time_millis(self):
        """Gets the processing_time_millis of this WebhookDeliveryStatusPayload.  # noqa: E501

        Time in milliseconds for delivery processing  # noqa: E501

        :return: The processing_time_millis of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: int
        """
        return self._processing_time_millis

    @processing_time_millis.setter
    def processing_time_millis(self, processing_time_millis):
        """Sets the processing_time_millis of this WebhookDeliveryStatusPayload.

        Time in milliseconds for delivery processing  # noqa: E501

        :param processing_time_millis: The processing_time_millis of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: int
        """

        self._processing_time_millis = processing_time_millis

    @property
    def received(self):
        """Gets the received of this WebhookDeliveryStatusPayload.  # noqa: E501

        Time event was received  # noqa: E501

        :return: The received of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: datetime
        """
        return self._received

    @received.setter
    def received(self, received):
        """Sets the received of this WebhookDeliveryStatusPayload.

        Time event was received  # noqa: E501

        :param received: The received of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: datetime
        """

        self._received = received

    @property
    def subject(self):
        """Gets the subject of this WebhookDeliveryStatusPayload.  # noqa: E501

        Email subject  # noqa: E501

        :return: The subject of this WebhookDeliveryStatusPayload.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this WebhookDeliveryStatusPayload.

        Email subject  # noqa: E501

        :param subject: The subject of this WebhookDeliveryStatusPayload.  # noqa: E501
        :type: str
        """

        self._subject = subject

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookDeliveryStatusPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookDeliveryStatusPayload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DmarcReportSourceSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source_ip': 'str',
        'count': 'int',
        'disposition': 'str',
        'dkim_aligned': 'bool',
        'spf_aligned': 'bool',
        'header_from': 'str'
    }

    attribute_map = {
        'source_ip': 'sourceIp',
        'count': 'count',
        'disposition': 'disposition',
        'dkim_aligned': 'dkimAligned',
        'spf_aligned': 'spfAligned',
        'header_from': 'headerFrom'
    }

    def __init__(self, source_ip=None, count=None, disposition=None, dkim_aligned=None, spf_aligned=None, header_from=None, local_vars_configuration=None):  # noqa: E501
        """DmarcReportSourceSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._source_ip = None
        self._count = None
        self._disposition = None
        self._dkim_aligned = None
        self._spf_aligned = None
        self._header_from = None
        self.discriminator = None

        self.source_ip = source_ip
        self.count = count
        self.disposition = disposition
        self.dkim_aligned = dkim_aligned
        self.spf_aligned = spf_aligned
        self.header_from = header_from

    @property
    def source_ip(self):
        """Gets the source_ip of this DmarcReportSourceSummary.  # noqa: E501


        :return: The source_ip of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: str
        """
        return self._source_ip

    @source_ip.setter
    def source_ip(self, source_ip):
        """Sets the source_ip of this DmarcReportSourceSummary.


        :param source_ip: The source_ip of this DmarcReportSourceSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source_ip is None:  # noqa: E501
            raise ValueError("Invalid value for `source_ip`, must not be `None`")  # noqa: E501

        self._source_ip = source_ip

    @property
    def count(self):
        """Gets the count of this DmarcReportSourceSummary.  # noqa: E501


        :return: The count of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this DmarcReportSourceSummary.


        :param count: The count of this DmarcReportSourceSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and count is None:  # noqa: E501
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    @property
    def disposition(self):
        """Gets the disposition of this DmarcReportSourceSummary.  # noqa: E501


        :return: The disposition of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: str
        """
        return self._disposition

    @disposition.setter
    def disposition(self, disposition):
        """Sets the disposition of this DmarcReportSourceSummary.


        :param disposition: The disposition of this DmarcReportSourceSummary.  # noqa: E501
        :type: str
        """

        self._disposition = disposition

    @property
    def dkim_aligned(self):
        """Gets the dkim_aligned of this DmarcReportSourceSummary.  # noqa: E501


        :return: The dkim_aligned of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: bool
        """
        return self._dkim_aligned

    @dkim_aligned.setter
    def dkim_aligned(self, dkim_aligned):
        """Sets the dkim_aligned of this DmarcReportSourceSummary.


        :param dkim_aligned: The dkim_aligned of this DmarcReportSourceSummary.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and dkim_aligned is None:  # noqa: E501
            raise ValueError("Invalid value for `dkim_aligned`, must not be `None`")  # noqa: E501

        self._dkim_aligned = dkim_aligned

    @property
    def spf_aligned(self):
        """Gets the spf_aligned of this DmarcReportSourceSummary.  # noqa: E501


        :return: The spf_aligned of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: bool
        """
        return self._spf_aligned

    @spf_aligned.setter
    def spf_aligned(self, spf_aligned):
        """Sets the spf_aligned of this DmarcReportSourceSummary.


        :param spf_aligned: The spf_aligned of this DmarcReportSourceSummary.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and spf_aligned is None:  # noqa: E501
            raise ValueError("Invalid value for `spf_aligned`, must not be `None`")  # noqa: E501

        self._spf_aligned = spf_aligned

    @property
    def header_from(self):
        """Gets the header_from of this DmarcReportSourceSummary.  # noqa: E501


        :return: The header_from of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: str
        """
        return self._header_from

    @header_from.setter
    def header_from(self, header_from):
        """Sets the header_from of this DmarcReportSourceSummary.


        :param header_from: The header_from of this DmarcReportSourceSummary.  # noqa: E501
        :type: str
        """

        self._header_from = header_from

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DmarcReportSourceSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DmarcReportSourceSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilitySimulationJobEventDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'event_type': 'str',
        'send_index': 'int',
        'entity_id': 'str',
        'target_label': 'str',
        'expectation_name': 'str',
        'attempt': 'int',
        'message': 'str',
        'error': 'str',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'event_type': 'eventType',
        'send_index': 'sendIndex',
        'entity_id': 'entityId',
        'target_label': 'targetLabel',
        'expectation_name': 'expectationName',
        'attempt': 'attempt',
        'message': 'message',
        'error': 'error',
        'created_at': 'createdAt'
    }

    def __init__(self, id=None, event_type=None, send_index=None, entity_id=None, target_label=None, expectation_name=None, attempt=None, message=None, error=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilitySimulationJobEventDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._event_type = None
        self._send_index = None
        self._entity_id = None
        self._target_label = None
        self._expectation_name = None
        self._attempt = None
        self._message = None
        self._error = None
        self._created_at = None
        self.discriminator = None

        self.id = id
        self.event_type = event_type
        self.send_index = send_index
        self.entity_id = entity_id
        self.target_label = target_label
        self.expectation_name = expectation_name
        self.attempt = attempt
        self.message = message
        self.error = error
        self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The id of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeliverabilitySimulationJobEventDto.


        :param id: The id of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def event_type(self):
        """Gets the event_type of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The event_type of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this DeliverabilitySimulationJobEventDto.


        :param event_type: The event_type of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event_type is None:  # noqa: E501
            raise ValueError("Invalid value for `event_type`, must not be `None`")  # noqa: E501
        allowed_values = ["JOB_CREATED", "JOB_STARTED", "JOB_PAUSED", "JOB_RESUMED", "JOB_CANCELLED", "JOB_COMPLETED", "JOB_FAILED", "SEND_SUCCESS", "SEND_FAILURE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_type` ({0}), must be one of {1}"  # noqa: E501
                .format(event_type, allowed_values)
            )

        self._event_type = event_type

    @property
    def send_index(self):
        """Gets the send_index of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The send_index of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: int
        """
        return self._send_index

    @send_index.setter
    def send_index(self, send_index):
        """Sets the send_index of this DeliverabilitySimulationJobEventDto.


        :param send_index: The send_index of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: int
        """

        self._send_index = send_index

    @property
    def entity_id(self):
        """Gets the entity_id of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The entity_id of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this DeliverabilitySimulationJobEventDto.


        :param entity_id: The entity_id of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def target_label(self):
        """Gets the target_label of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The target_label of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._target_label

    @target_label.setter
    def target_label(self, target_label):
        """Sets the target_label of this DeliverabilitySimulationJobEventDto.


        :param target_label: The target_label of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """

        self._target_label = target_label

    @property
    def expectation_name(self):
        """Gets the expectation_name of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The expectation_name of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._expectation_name

    @expectation_name.setter
    def expectation_name(self, expectation_name):
        """Sets the expectation_name of this DeliverabilitySimulationJobEventDto.


        :param expectation_name: The expectation_name of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """

        self._expectation_name = expectation_name

    @property
    def attempt(self):
        """Gets the attempt of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The attempt of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: int
        """
        return self._attempt

    @attempt.setter
    def attempt(self, attempt):
        """Sets the attempt of this DeliverabilitySimulationJobEventDto.


        :param attempt: The attempt of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: int
        """

        self._attempt = attempt

    @property
    def message(self):
        """Gets the message of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The message of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this DeliverabilitySimulationJobEventDto.


        :param message: The message of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def error(self):
        """Gets the error of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The error of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this DeliverabilitySimulationJobEventDto.


        :param error: The error of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def created_at(self):
        """Gets the created_at of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The created_at of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DeliverabilitySimulationJobEventDto.


        :param created_at: The created_at of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilitySimulationJobEventDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilitySimulationJobEventDto):
            return True

        return self.to_dict() != other.to_dict()
